@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ public:
     explicit AddresseeLineEditAkonadi();
     ~AddresseeLineEditAkonadi();
 
-    Akonadi::Session *akonadiSession() const;
+    [[nodiscard]] Akonadi::Session *akonadiSession() const;
 
 private:
     mutable Akonadi::Session *m_akonadiSession = nullptr;
